/* ***** BEGIN LICENSE BLOCK *****
 * Licensed under Version: MPL 1.1/GPL 2.0/LGPL 2.1
 * Full Terms at http://mozile.mozdev.org/license.html
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Playsophy code.
 *
 * The Initial Developer of the Original Code is Playsophy
 * Portions created by the Initial Developer are Copyright (C) 2002-2003
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *	Karl Guertin <grayrest@grayrest.com>
 *	James A. Overton <james@overton.ca>
 *	Christian Stocker (Bitflux)
 *	Paul Everitt
 *	David Palm
 *
 * ***** END LICENSE BLOCK ***** */

/**
@fileoverview
Mozile Main Javascript.

Global variables and initialisation functions.
*/

/* === Global Variables === */

//Mozile Constants
const MOZILEC = new Object();			//Global object for constants.
MOZILEC.EXTENSION_DIR = "chrome://mozile/content/eDOM/";
MOZILEC.MES_DIR = "chrome://mozile/content/mes/";
MOZILEC.MES_DEFAULT = "chrome://mozile/content/mes/mes-XHTML-en-US.xml";
MOZILEC.TAGS_XHTML = "chrome://mozile/content/mes/tags-XHTML.css";
MOZILEC.HOME = "http://mozile.mozdev.org/";
MOZILEC.HELP = "chrome://mozile/content/docs/index.html";
MOZILEC.DEMO = "chrome://mozile/content/demo/mozileDemo.html";
MOZILEC.NAMESPACE_XHTML = "http://www.w3.org/1999/xhtml";

var mozileTarget = "";         // the currently focussed window, if it has loaded Mozile.
var mozileSelection = "";      // the eDOM selection of the currently focussed window.
var mozilePrefs = "";          // Netscape preferences component

var mozile = new Object();     //Global Mozile object.
mozile.startup=true;
mozile.lastContextNode = null;  //The last detected node.
mozile.keyMax = 20;             // the number of key presses before the state is saved to the Undo Stack.
mozile.undoMax = 100;           // the number of undo steps available.

/* === Inline code to execute on startup === */

	document.addEventListener("load", mozileStartup, true);

/* === Startup Functions === */

/**
Initialise toolbar variables.
Note: can't have onload handler for overlay file, hence it must be done this way. 
*/
function mozileStartup() {
	mozilePrefsInit();
	mozileTools.init();
	mozile.strings=document.getElementById("mozile-strings");
	document.removeEventListener("load", mozileStartup, true);
	if ( mozilePrefs.getBoolPref("mozile.onBool") ) {
		mozileSwitchOn();
	} else {
		mozileSwitchOff();
	}
	mozileDetect();
	mozile.startup=false;
}

/* === Mozile Preferences === */

const mozileDefaultPrefs = [
["mozile.acceleratorBool",false],
["mozile.autohideBool",false],
["mozile.caretAlwaysOnBool",false],
["mozile.debugLevelInt",0],
["mozile.onBool",true],
["mozile.promptOnUnloadBool",true],
["mozile.saveContentString","page"],
["mozile.saveMethodString","display"],
["mozile.saveHttpPathString",""],
["mozile.MESDefaultString","mes-XHTML-en-US.xml"],
["mozile.MESExternalString",""],
["mozile.MESUseExternalBool",false]
];

/*
Note that the caret preference "mozile.caretAlwaysOnBool" mirrors "accessibility.browsewithcaret"
when it is first set.
*/
function mozilePrefsInit() {
	// The caret requires added privileges. (from Chrome???)
	netscape.security.PrivilegeManager.enablePrivilege('UniversalXPConnect');
	mozilePrefs = Components.classes['@mozilla.org/preferences-service;1'].getService(Components.interfaces.nsIPrefService).getBranch(null);	
	try {
		var p;
		for ( var i=0; i<mozileDefaultPrefs.length; i++ ) {
			p = mozileDefaultPrefs[i];
			if ( !mozilePrefs.prefHasUserValue(p[0]) ) {
				if ( p[0] == "mozile.caretAlwaysOnBool" ) {
					mozilePrefs.setBoolPref(p[0],mozilePrefs.getBoolPref('accessibility.browsewithcaret'));
				} else if ( p[0].substr(-4) == "Bool" ) {
					mozilePrefs.setBoolPref(p[0],p[1]);
				} else if ( p[0].substr(-3) == "Int" ) {
					mozilePrefs.setIntPref(p[0],p[1]);
				} else if ( p[0].substr(-6) == "String"  ) {
					mozilePrefs.setCharPref(p[0],p[1]);
				}
			}
		}
	}catch (e) {
		alert ("[mozileMain.js] mozilePrefsInit: "+e)
	}
}



